@@ -411,7 +411,7 @@ gdk_mir_display_create_window_impl (GdkDisplay    *display,
 
   if (attributes->wclass == GDK_INPUT_OUTPUT)
     {
-      window->impl = _gdk_mir_window_impl_new ();
+      window->impl = _gdk_mir_window_impl_new (display, window, attributes, attributes_mask);
       window->impl_window = window;
     }
   else /* attributes->wclass == GDK_INPUT_ONLY */
