@@ -116,15 +116,15 @@ end_startup_notification (GdkDisplay *display,
 
 
 /* This should be fairly long, as it's confusing to users if a startup
- * ends when it shouldn't (it appears that the startup failed, and
+ * ends when it shouldn’t (it appears that the startup failed, and
  * they have to relaunch the app). Also the timeout only matters when
- * there are bugs and apps don't end their own startup sequence.
+ * there are bugs and apps don’t end their own startup sequence.
  *
  * This timeout is a "last resort" timeout that ignores whether the
  * startup sequence has shown activity or not.  Metacity and the
  * tasklist have smarter, and correspondingly able-to-be-shorter
- * timeouts. The reason our timeout is dumb is that we don't monitor
- * the sequence (don't use an SnMonitorContext)
+ * timeouts. The reason our timeout is dumb is that we don’t monitor
+ * the sequence (don’t use an SnMonitorContext)
  */
 #define STARTUP_TIMEOUT_LENGTH_SECONDS 30
 #define STARTUP_TIMEOUT_LENGTH (STARTUP_TIMEOUT_LENGTH_SECONDS * 1000)
@@ -159,8 +159,7 @@ free_startup_timeout (void *data)
 
   std = data;
 
-  g_slist_foreach (std->contexts, (GFunc) free_startup_notification_data, NULL);
-  g_slist_free (std->contexts);
+  g_slist_free_full (std->contexts, free_startup_notification_data);
 
   if (std->timeout_id != 0)
     {
@@ -464,10 +463,16 @@ GdkAppLaunchContext *
 _gdk_x11_display_get_app_launch_context (GdkDisplay *display)
 {
   GdkAppLaunchContext *ctx;
+  const gchar *display_name;
 
   ctx = g_object_new (GDK_TYPE_X11_APP_LAUNCH_CONTEXT,
                       "display", display,
                       NULL);
 
+  display_name = gdk_display_get_name (display);
+  if (display_name)
+    g_app_launch_context_setenv (G_APP_LAUNCH_CONTEXT (ctx),
+                                 "DISPLAY", display_name);
+
   return ctx;
 }
