@@ -1504,6 +1504,23 @@ gtk_notebook_tab_get_type (void)
     return etype;
 }
 
+/* enumerations from "gtkpadcontroller.h" */
+GType
+gtk_pad_action_type_get_type (void)
+{
+    static GType etype = 0;
+    if (G_UNLIKELY(etype == 0)) {
+        static const GEnumValue values[] = {
+            { GTK_PAD_ACTION_BUTTON, "GTK_PAD_ACTION_BUTTON", "button" },
+            { GTK_PAD_ACTION_RING, "GTK_PAD_ACTION_RING", "ring" },
+            { GTK_PAD_ACTION_STRIP, "GTK_PAD_ACTION_STRIP", "strip" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static (g_intern_static_string ("GtkPadActionType"), values);
+    }
+    return etype;
+}
+
 /* enumerations from "gtkplacessidebar.h" */
 GType
 gtk_places_open_flags_get_type (void)
